import { SentenceAction } from '../../schema/domain';
import { ExecuteResult, Query, QueryOptions } from '../../query/domain';
import { Transaction } from '.';
export interface ActionObserverArgs {
    query: Query;
    data: any;
    options: QueryOptions;
    result?: any;
    error?: any;
}
export declare abstract class ActionObserver {
    actions: SentenceAction[];
    condition?: string;
    transactional?: boolean;
    constructor(actions: SentenceAction[], condition?: string, transactional?: boolean);
    before(args: ActionObserverArgs): Promise<void>;
    after(args: ActionObserverArgs): Promise<void>;
    error(args: ActionObserverArgs): Promise<void>;
}
export interface Executor {
    execute(query: Query, data: any, options: QueryOptions): Promise<any>;
    executeList(queries: Query[], options: QueryOptions): Promise<ExecuteResult[]>;
    transaction(options: QueryOptions, callback: {
        (tr: Transaction): Promise<void>;
    }): Promise<void>;
}
export interface ObservableExecutor {
    subscribe(observer: ActionObserver): void;
    unsubscribe(observer: ActionObserver): void;
}
