"use strict";
/* eslint-disable @typescript-eslint/ban-types */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExpressionFacade = void 0;
const queryHelper_1 = require("./services/queryHelper");
const plan_1 = require("./useCases/plan");
const queryBuilder_1 = require("./services/queryBuilder");
const queryBuilderCacheDecorator_1 = require("./services/queryBuilderCacheDecorator");
const execute_1 = require("./useCases/execute");
class ExpressionFacade {
    constructor(sentenceFacade, schemaFacade, languages, executor, expressions, cache, helper) {
        this.sentenceFacade = sentenceFacade;
        this.schemaFacade = schemaFacade;
        this.languages = languages;
        this.builder = new queryBuilderCacheDecorator_1.QueryBuilderCacheDecorator(new queryBuilder_1.QueryBuilder(this.sentenceFacade, this.schemaFacade, this.languages), cache, helper);
        this.getQueryPlan = new plan_1.GeQueryPlan(this.builder);
        this.queryHelper = new queryHelper_1.QueryHelper(this.schemaFacade.stage, this.schemaFacade.view);
        this.expressionExecute = new execute_1.ExpressionExecute(this.builder, executor, expressions);
    }
    build(expression, options) {
        return this.builder.build(expression, this.solveOptions(options));
    }
    plan(expression, options) {
        return this.getQueryPlan.plan(expression, this.solveOptions(options));
    }
    solveOptions(options) {
        return this.queryHelper.solveOptions(options);
    }
    execute(expression, data = {}, options) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.expressionExecute.execute(expression, data, this.solveOptions(options));
        });
    }
    executeList(expressions, options) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.expressionExecute.executeList(expressions, this.solveOptions(options));
        });
    }
    transaction(options = undefined, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.expressionExecute.transaction(this.solveOptions(options), callback);
        });
    }
}
exports.ExpressionFacade = ExpressionFacade;
//# sourceMappingURL=facade.js.map